pub struct ColumnType {
pub span_range: Range<usize>,
pub raw: String,
pub type_name: ColumnTypeName,
pub args: Vec<Value>,
pub arrays: Vec<Option<u32>>,
}Expand description
Represents details of the table column.
Fields
span_range: Range<usize>The range of the span in the source text.
raw: StringThe raw type including type name, args, and arrays.
type_name: ColumnTypeNameThe parsed data type.
args: Vec<Value>Type arguments.
arrays: Vec<Option<u32>>Type arrays.