pub struct IndexesBlock {
pub span_range: Range<usize>,
pub defs: Vec<IndexesDef>,
}Expand description
Represents an indexes block inside a table block. Indexes allow users to quickly locate and access the data. Users can define single or multi-column indexes.
Fields
span_range: Range<usize>The range of the span in the source text.
defs: Vec<IndexesDef>Defined items inside an indexes block.