pub struct IndexesDef {
pub span_range: Range<usize>,
pub cols: Vec<IndexesColumnType>,
pub settings: Option<IndexesSettings>,
}Expand description
Represents an indexes definition or each item in an indexes block.
Fields
span_range: Range<usize>The range of the span in the source text.
cols: Vec<IndexesColumnType>Table column names for indexing which can be composite.
settings: Option<IndexesSettings>A Configuration for the specified column names.