pub struct RefSettings {
pub span_range: Range<usize>,
pub attributes: Vec<Attribute>,
pub on_delete: Option<ReferentialAction>,
pub on_update: Option<ReferentialAction>,
}Fields
span_range: Range<usize>The range of the span in the source text.
attributes: Vec<Attribute>A vector of key and optional value pairs representing attributes of the ref.
on_delete: Option<ReferentialAction>on_update: Option<ReferentialAction>Trait Implementations
Sourceimpl Clone for RefSettings
impl Clone for RefSettings
Sourceimpl Debug for RefSettings
impl Debug for RefSettings