pub struct TableColumn {
pub span_range: Range<usize>,
pub name: Ident,
pub type: ColumnType,
pub settings: Option<ColumnSettings>,
}Expand description
Represents a single column or field of the table.
Fields
span_range: Range<usize>The range of the span in the source text.
name: IdentThe column name.
type: ColumnTypeThe data type of the column.
settings: Option<ColumnSettings>The settings of the column.