pub struct TableSettings {
pub span_range: Range<usize>,
pub attributes: Vec<Attribute>,
}Expand description
Represents settings of the table.
Fields
span_range: Range<usize>The range of the span in the source text.
attributes: Vec<Attribute>A vector of key and optional value pairs representing attributes of the table.